@@ -4,6 +4,12 @@ use Oryx::Value;
 
 use base qw(Oryx::Attribute);
 
+sub create {
+    my ($self, $query, $param) = @_;
+    my $attr_name = $self->name;
+    $param->{$attr_name} = $self->typeClass->deflate($param->{$attr_name});
+}
+
 sub retrieve {
     my ($self, $query, $values) = @_;
     push @{$query->{fields}}, $self->name;
@@ -12,13 +18,8 @@ sub retrieve {
 sub update {
     my ($self, $query, $object) = @_;
     my $attr_name = $self->name;
-    if (ref tied($object->{$attr_name})
-    eq 'Oryx::Value::Complex') {
-	$query->{fieldvals}->{$attr_name} =
-            tied($object->{$attr_name})->dump;
-    } else {
-	$query->{fieldvals}->{$attr_name} = $object->$attr_name;
-    }
+    my $value = $object->$attr_name;
+    $query->{fieldvals}->{$attr_name} = $self->typeClass->deflate($value);
 }
 
 sub search {
